# Security Policy

Mozilla has a [well-defined process for handling security vulnerabilities](https://www.mozilla.org/en-US/about/governance/policies/security-group/bugs/) based around responsible disclosure.

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| > 1.x   | :white_check_mark: |
| < 1.0   | :x:                |

## Reporting a Vulnerability

If you believe you have found a Remote Settings related security vulnerability, you should visit the [Mozilla bug bounty program](https://www.mozilla.org/en-US/security/bug-bounty/) for information on how to submit them.
